@@ -120,6 +120,11 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
+    # Create the log file, and set some rights on it in order to prevent
+    # unwanted access
+    open(log_path, 'a').close()
+    os.chmod(log_path, 0o640)
+
     config.set('defaults', 'forks', str(min(
         multiprocessing.cpu_count() * 4, 100)))
     config.set('defaults', 'timeout', '30')
@@ -130,6 +135,11 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
                '~/.ansible/fact_cache')
+    # NOTE(mwhahaha): only gather the bare minimum facts because this has
+    # direct impact on how fast ansible can go.
+    config.set('defaults', 'gather_subset', '!all,min')
+    # NOTE(mwhahaha): this significantly affects performation per ansible#73654
+    config.set('defaults', 'inject_facts_as_vars', 'false')
 
     # Set the pull interval to lower CPU overhead
     config.set('defaults', 'internal_poll_interval', '0.01')
